Package: via
Type: Package
Title: Virtual Arrays
Version: 0.2.0
Authors@R: c(
	person(given="Adam T.", family="Kocsis", role=c("cre", "aut"),
		   email="adam.t.kocsis@gmail.com", comment=c(ORCID="0000-0002-9028-665X")),
	person(given="Deutsche Forschungsgemeinschaft", role="fnd"),
	person(given="FAU GeoZentrum Nordbayern", role="fnd"))
Collate: zzz.R data.R generics.R utility.R classes.R
        VirtualArray-base.R VirtualArray-xattrib.R
        VirtualArray-subset.R VirtualArray-replace.R
        VirtualArray-combine.R XArray-base.R XArray-xattrib.R
        XArray-combine.R RasterArray-base.R RasterArray-xattrib.R
        RasterArray-groupgen.R RasterArray-replace.R
        RasterArray-combine.R RasterArray-rast.R SfcArray-base.R
        SfcArray-replace.R SfcArray-sf.R SfArray-base.R
        SfArray-replace.R conversions.R
Maintainer: Adam T. Kocsis <adam.t.kocsis@gmail.com>
Description: The base class 'VirtualArray' is defined, which acts as a wrapper around lists allowing users to fold arbitrary sequential data into n-dimensional, R-style virtual arrays. The derived 'XArray' class is defined to be used for homogeneous lists that contain a single class of objects. The 'RasterArray' and 'SfArray' classes enable the use of stacked spatial data instead of lists.
License: CC BY 4.0
Date: 2023-05-15
BugReports: https://github.com/adamkocsis/via
Encoding: UTF-8
LazyData: false
Depends: R (>= 4.0.0)
Imports: methods
NeedsCompilation: no
RoxygenNote: 7.2.3
Suggests: tinytest, knitr, rmarkdown, terra, sp, sf
Packaged: 2023-05-16 13:20:28 UTC; root
Author: Adam T. Kocsis [cre, aut] (<https://orcid.org/0000-0002-9028-665X>),
  Deutsche Forschungsgemeinschaft [fnd],
  FAU GeoZentrum Nordbayern [fnd]
Repository: CRAN
Date/Publication: 2023-05-16 13:50:02 UTC
Built: R 4.6.0; ; 2026-04-27 05:15:14 UTC; unix
