# Generated by roxygen2: do not edit by hand

S3method(is.na,RasterArray)
S3method(st_bbox,SfcArray)
S3method(st_crs,SfcArray)
S3method(st_transform,SfcArray)
export(RasterArray)
export(SfArray)
export(SfcArray)
export(XArray)
export(as.SfArray)
export(as.SfcArray)
export(as.XArray)
export(colnums)
export(ext)
export(newbounds)
export(nums)
export(nvalues)
export(project)
export(rastex)
export(res)
export(resample)
export(rownums)
export(st_bbox)
export(st_crs)
export(st_transform)
export(xres)
export(yres)
exportClasses(RasterArray)
exportClasses(SfArray)
exportClasses(SfcArray)
exportClasses(XArray)
exportMethods("[")
exportMethods("[<-")
exportMethods("[[")
exportMethods("[[<-")
exportMethods("colnames<-")
exportMethods("dimnames<-")
exportMethods("names<-")
exportMethods("rownames<-")
exportMethods(aggregate)
exportMethods(c)
exportMethods(colnames)
exportMethods(crop)
exportMethods(dim)
exportMethods(dimlayer)
exportMethods(dimnames)
exportMethods(disagg)
exportMethods(layers)
exportMethods(length)
exportMethods(names)
exportMethods(ncell)
exportMethods(ncol)
exportMethods(nlayers)
exportMethods(nrow)
exportMethods(proxy)
exportMethods(rownames)
exportMethods(subset)
exportMethods(t)
importFrom(methods,"as<-")
importFrom(methods,"slot<-")
importFrom(methods,as)
importFrom(methods,cbind2)
importFrom(methods,new)
importFrom(methods,rbind2)
importFrom(methods,slot)
