# Via: a command line tool to initialize your repos

Initialize your repository.

## Feature

- [x] `.gitignore`
- [x] `License`

## Tutorial

```sh
# download python .gitignore file and MIT License
# file will be saved to current dir
via -i python -l mit
# print to stdout
via -i python --print
```

## Support

### Ignore

All the files are downloaded from [github/gitignore](https://github.com/github/gitignore)

### License

All the licenses are downloaded through [GitHub License API](https://developer.github.com/v3/licenses/).

* GPL-2.0
* Unlicense
* BSD-2-Clause
* LGPL-2.1
* GPL-3.0
* MIT
* BSD-3-Clause
* Apache-2.0
* EPL-2.0
* MPL-2.0
* LGPL-3.0
* AGPL-3.0
